@@ -65,14 +65,6 @@ char *strncpy(char *dest, const char *src, size_t n) __THROW;
 #include	"md_u.h"
 #include	"md_p.h"
 
-/* general information that might be extracted from a superblock */
-struct mdinfo {
-	mdu_array_info_t	array;
-	mdu_disk_info_t		disk;
-	__u64			events;
-	unsigned int		uuid[4];
-};
-
 #define Name "mdadm"
 
 enum mode {
@@ -106,7 +98,7 @@ typedef struct mddev_ident_s {
 	char	*devname;
 	
 	int	uuid_set;
-	__u32	uuid[4];
+	int	uuid[4];
 
 	unsigned int super_minor;
 
@@ -116,7 +108,6 @@ typedef struct mddev_ident_s {
 	int	level;
 	unsigned int raid_disks;
 	unsigned int spare_disks;
-	struct supertype *st;
 	int	autof;		/* 1 for normal, 2 for partitioned */
 	char	*spare_group;
 
@@ -163,38 +154,22 @@ extern mapping_t r5layout[], pers[], modes[], faultylayout[];
 
 extern char *map_dev(int major, int minor);
 
+#ifdef UCLIBC
+  struct FTW {};
+# define FTW_PHYS 1
+#else
+# define  __USE_XOPEN_EXTENDED
+# include <ftw.h>
+# ifdef __dietlibc__
+#  define FTW_PHYS 1
+# endif
+#endif
 
-extern struct superswitch {
-	void (*examine_super)(void *sbv);
-	void (*brief_examine_super)(void *sbv);
-	void (*detail_super)(void *sbv);
-	void (*brief_detail_super)(void *sbv);
-	void (*uuid_from_super)(int uuid[4], void *sbv);
-	void (*getinfo_super)(struct mdinfo *info, void *sbv);
-	int (*update_super)(struct mdinfo *info, void *sbv, char *update, char *devname, int verbose);
-	__u64 (*event_super)(void *sbv);
-	int (*init_super)(void **sbp, mdu_array_info_t *info);
-	void (*add_to_super)(void *sbv, mdu_disk_info_t *dinfo);
-	int (*store_super)(int fd, void *sbv);
-	int (*write_init_super)(struct supertype *st, void *sbv, mdu_disk_info_t *dinfo, char *devname);
-	int (*compare_super)(void **firstp, void *secondv);
-	int (*load_super)(struct supertype *st, int fd, void **sbp, char *devname);
-	struct supertype * (*match_metadata_desc)(char *arg);
-	__u64 (*avail_size)(__u64 size);
-	int major;
-} super0, super1, *superlist[];
-
-struct supertype {
-	struct superswitch *ss;
-	int minor_version;
-};
-
-extern struct supertype *super_by_version(int vers, int minor);
-extern struct supertype *guess_super(int fd);
+extern int add_dev(const char *name, const struct stat *stb, int flag, struct FTW *s);
 
 
 extern int Manage_ro(char *devname, int fd, int readonly);
-extern int Manage_runstop(char *devname, int fd, int runstop);
+extern int Manage_runstop(char *devname, int fd, int runstop, int quiet);
 extern int Manage_resize(char *devname, int fd, long long size, int raid_disks);
 extern int Manage_reconfig(char *devname, int fd, int layout);
 extern int Manage_subdevs(char *devname, int fd,
@@ -202,7 +177,7 @@ extern int Manage_subdevs(char *devname, int fd,
 extern int Grow_Add_device(char *devname, int fd, char *newdev);
 
 
-extern int Assemble(struct supertype *st, char *mddev, int mdfd,
+extern int Assemble(char *mddev, int mdfd,
 		    mddev_ident_t ident,
 		    char *conffile,
 		    mddev_dev_t devlist,
@@ -215,15 +190,14 @@ extern int Build(char *mddev, int mdfd, int chunk, int level, int layout,
 		 mddev_dev_t devlist, int assume_clean);
 
 
-extern int Create(struct supertype *st, char *mddev, int mdfd,
+extern int Create(char *mddev, int mdfd,
 		  int chunk, int level, int layout, unsigned long size, int raiddisks, int sparedisks,
 		  int subdevs, mddev_dev_t devlist,
 		  int runstop, int verbose, int force);
 
 extern int Detail(char *dev, int brief, int test);
 extern int Query(char *dev);
-extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust,
-		   struct supertype *forcest);
+extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust);
 extern int Monitor(mddev_dev_t devlist,
 		   char *mailaddr, char *alert_cmd,
 		   int period, int daemonise, int scan, int oneshot,
@@ -239,7 +213,7 @@ extern int check_reiser(int fd, char *name);
 extern int check_raid(int fd, char *name);
 
 extern int get_mdp_major(void);
-extern int is_standard(char *dev);
+extern int is_standard(char *dev, int *nump);
 
 
 extern mddev_ident_t conf_get_ident(char *conffile, char *dev);
@@ -250,10 +224,11 @@ extern char *conf_line(FILE *file);
 extern char *conf_word(FILE *file, int allow_key);
 extern void free_line(char *line);
 extern int match_oneof(char *devices, char *devname);
+extern int load_super(int fd, mdp_super_t *super);
 extern void uuid_from_super(int uuid[4], mdp_super_t *super);
 extern int same_uuid(int a[4], int b[4]);
-/* extern int compare_super(mdp_super_t *first, mdp_super_t *second);*/
-extern unsigned long calc_csum(void *super, int bytes);
+extern int compare_super(mdp_super_t *first, mdp_super_t *second);
+extern unsigned long calc_sb_csum(mdp_super_t *super);
 extern int store_super(int fd, mdp_super_t *super);
 extern int enough(int level, int raid_disks, int avail_disks);
 extern int ask(char *mesg);
@@ -293,3 +268,14 @@ extern int open_mddev(char *dev, int autof);
 
 #define	ModeMask	0x1f
 #define	ModeShift	5
+
+
+#ifdef __TINYC__
+#undef minor
+#undef major
+#undef makedev
+#define minor(x) ((x)&0xff)
+#define major(x) (((x)>>8)&0xff)
+#define makedev(M,m) (((M)<<8) | (m))
+#endif
+
